Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(660)

Unified Diff: content/utility/utility_thread_impl.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/shell/utility/shell_content_utility_client.cc ('k') | content/utility/utility_thread_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/utility/utility_thread_impl.h
diff --git a/content/utility/utility_thread_impl.h b/content/utility/utility_thread_impl.h
index 234326a43c439fcec8a4b9f83f1425e736d30dd9..487a74839ac5627aaf1ee73c6dd4d574b840f2cf 100644
--- a/content/utility/utility_thread_impl.h
+++ b/content/utility/utility_thread_impl.h
@@ -56,18 +56,21 @@ class UtilityThreadImpl : public UtilityThread,
void OnBatchModeStarted();
void OnBatchModeFinished();
- void BindServiceFactoryRequest(shell::mojom::ServiceFactoryRequest request);
+ void BindServiceFactoryRequest(
+ service_manager::mojom::ServiceFactoryRequest request);
// True when we're running in batch mode.
bool batch_mode_;
std::unique_ptr<UtilityBlinkPlatformImpl> blink_platform_impl_;
- // shell::mojom::ServiceFactory for shell::Service hosting.
+ // service_manager::mojom::ServiceFactory for service_manager::Service
+ // hosting.
std::unique_ptr<UtilityServiceFactory> service_factory_;
- // Bindings to the shell::mojom::ServiceFactory impl.
- mojo::BindingSet<shell::mojom::ServiceFactory> service_factory_bindings_;
+ // Bindings to the service_manager::mojom::ServiceFactory impl.
+ mojo::BindingSet<service_manager::mojom::ServiceFactory>
+ service_factory_bindings_;
DISALLOW_COPY_AND_ASSIGN(UtilityThreadImpl);
};
« no previous file with comments | « content/shell/utility/shell_content_utility_client.cc ('k') | content/utility/utility_thread_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698